@@ -1,4 +1,4 @@
-# Copyright (c) 2013-2017 Christian Geier et al.
+# Copyright (c) 2013-2021 khal contributors
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -27,11 +27,11 @@ import sys
 import click
 import urwid
 
-from .. import utils
+from .. import icalendar as icalendar_helpers, utils
 from ..khalendar.event import Event
 from ..khalendar.exceptions import ReadOnlyCalendarError
 from . import colors
-from .widgets import ExtendedEdit as Edit, NPile, NColumns, NListBox, linebox
+from .widgets import ExtendedEdit as Edit, NPile, NColumns, linebox
 from .base import Pane, Window
 from .editor import EventEditor, ExportDialog
 from .calendarwidget import CalendarWidget
@@ -131,11 +131,11 @@ class DateHeader(SelectableText):
         weekday = day.strftime('%A')
         daystr = day.strftime(dtformat)
         if day == dt.date.today():
-            return 'Today ({}, {})'.format(weekday, daystr)
+            return f'Today ({weekday}, {daystr})'
         elif day == dt.date.today() + dt.timedelta(days=1):
-            return 'Tomorrow ({}, {})'.format(weekday, daystr)
+            return f'Tomorrow ({weekday}, {daystr})'
         elif day == dt.date.today() - dt.timedelta(days=1):
-            return 'Yesterday ({}, {})'.format(weekday, daystr)
+            return f'Yesterday ({weekday}, {daystr})'
 
         approx_delta = utils.relative_timedelta_str(day)
 
@@ -167,8 +167,8 @@ class U_Event(urwid.Text):
         """
         if relative:
             if isinstance(this_date, dt.datetime) or not isinstance(this_date, dt.date):
-                raise ValueError('`this_date` is of type `{}`, sould be '
-                                 '`datetime.date`'.format(type(this_date)))
+                raise ValueError(f'`this_date` is of type `{type(this_date)}`, '
+                                 'should be `datetime.date`')
         self.event = event
         self.delete_status = delete_status
         self.this_date = this_date
@@ -255,7 +255,10 @@ class EventListBox(urwid.ListBox):
 
     @property
     def focus_event(self):
-        return self.focus.original_widget
+        if self.focus is None:
+            return None
+        else:
+            return self.focus.original_widget
 
     def refresh_titles(self, min_date, max_date, everything):
         """Refresh only the currently focused event's title
@@ -354,7 +357,7 @@ class DayWalker(urwid.SimpleFocusListWalker):
         self._first_day = this_date
         self._collection = collection
 
-        super().__init__(list())
+        super().__init__([])
         self.ensure_date(this_date)
 
     def ensure_date(self, day):
@@ -467,7 +470,7 @@ class DayWalker(urwid.SimpleFocusListWalker):
 
         :type day: datetime.date
         """
-        event_list = list()
+        event_list = []
         date_header = DateHeader(
             day=day,
             dateformat=self._conf['locale']['longdateformat'],
@@ -552,7 +555,7 @@ class StaticDayWalker(DayWalker):
         return urwid.SimpleFocusListWalker.set_focus(self, position)
 
 
-class DateListBox(NListBox):
+class DateListBox(urwid.ListBox):
     """A ListBox container for a SimpleFocusListWalker, that contains one day
     worth of events"""
 
@@ -563,7 +566,7 @@ class DateListBox(NListBox):
         super().__init__(content)
 
     def __repr__(self):
-        return '<DateListBox {}>'.format(self.date)
+        return f'<DateListBox {self.date}>'
 
     __str__ = __repr__
 
@@ -693,7 +696,7 @@ class EventColumn(urwid.WidgetWrap):
         """
         if event.readonly:
             self.pane.window.alert(
-                ('alert', 'Calendar `{}` is read-only.'.format(event.calendar)))
+                ('alert', f'Calendar `{event.calendar}` is read-only.'))
             return
 
         if isinstance(event.start_local, dt.datetime):
@@ -733,12 +736,12 @@ class EventColumn(urwid.WidgetWrap):
 
         assert not self.editor
         if external_edit:
-            self.pane.window.loop.screen.stop()
+            self.pane.window.loop.stop()
             text = click.edit(event.raw)
-            self.pane.window.loop.screen.start()
+            self.pane.window.loop.start()
             if text is None:
                 return
-            # KeyErrors can occurr here when we destroy DTSTART,
+            # KeyErrors can occur here when we destroy DTSTART,
             # otherwise, even broken .ics files seem to be no problem
             new_event = Event.fromString(
                 text,
@@ -808,7 +811,7 @@ class EventColumn(urwid.WidgetWrap):
 
         if event.event.readonly:
             self.pane.window.alert(
-                ('alert', 'Calendar {} is read-only.'.format(event.event.calendar)),
+                ('alert', f'Calendar {event.event.calendar} is read-only.'),
             )
             return
         status = self.delete_status(event.recuid)
@@ -871,16 +874,18 @@ class EventColumn(urwid.WidgetWrap):
         if not self.pane.collection.writable_names:
             self.pane.window.alert(('alert', 'No writable calendar.'))
             return
+        if date is None:
+            date = dt.datetime.now()
         if end is None:
             start = dt.datetime.combine(date, dt.time(dt.datetime.now().hour))
             end = start + dt.timedelta(minutes=60)
-            event = utils.new_event(
+            event = icalendar_helpers.new_event(
                 dtstart=start, dtend=end, summary='',
                 timezone=self._conf['locale']['default_timezone'],
                 locale=self._conf['locale'],
             )
         else:
-            event = utils.new_event(
+            event = icalendar_helpers.new_event(
                 dtstart=date, dtend=end + dt.timedelta(days=1), summary='',
                 allday=True, locale=self._conf['locale'],
             )
@@ -955,21 +960,24 @@ class EventDisplay(urwid.WidgetWrap):
         if event.categories != '':
             lines.append(urwid.Text('Categories: ' + event.categories))
 
+        if event.url != '':
+            lines.append(urwid.Text('URL: ' + event.url))
+
         # start and end time/date
         if event.allday:
             startstr = event.start_local.strftime(self._conf['locale']['dateformat'])
             endstr = event.end_local.strftime(self._conf['locale']['dateformat'])
         else:
             startstr = event.start_local.strftime(
-                '{} {}'.format(self._conf['locale']['dateformat'],
-                               self._conf['locale']['timeformat'])
+                f"{self._conf['locale']['dateformat']} "
+                f"{self._conf['locale']['timeformat']}"
             )
             if event.start_local.date == event.end_local.date:
                 endstr = event.end_local.strftime(self._conf['locale']['timeformat'])
             else:
                 endstr = event.end_local.strftime(
-                    '{} {}'.format(self._conf['locale']['dateformat'],
-                                   self._conf['locale']['timeformat'])
+                    f"{self._conf['locale']['dateformat']} "
+                    f"{self._conf['locale']['timeformat']}"
                 )
 
         if startstr == endstr:
@@ -1061,6 +1069,8 @@ class ClassicView(Pane):
             elistbox.set_focus_date_callback = lambda _: None
         self.calendar = ContainerWidget(calendar)
         self.lwidth = 31 if self._conf['locale']['weeknumbers'] == 'right' else 28
+        if self._conf['view']['frame'] in ["width", "color"]:
+            self.lwidth += 2
         columns = NColumns(
             [(self.lwidth, self.calendar), self.eventscolumn],
             dividechars=0,
@@ -1120,7 +1130,7 @@ class ClassicView(Pane):
     def _search(self, search_term):
         """search for events matching `search_term"""
         self.window.backtrack()
-        events = list(self.collection.search(search_term))
+        events = sorted(self.collection.search(search_term))
         event_list = []
         event_list.extend([
             urwid.AttrMap(
@@ -1143,14 +1153,14 @@ class ClassicView(Pane):
         )
         pane = Pane(
             columns,
-            title="Search results for \"{}\" (Esc for backtrack)".format(search_term),
+            title=f"Search results for \"{search_term}\" (Esc for backtrack)",
         )
         pane._conf = self._conf
         columns.set_focus_column(1)
         self.window.open(pane)
 
     def render(self, size, focus=False):
-        rval = super(ClassicView, self).render(size, focus)
+        rval = super().render(size, focus)
         if self.init:
             # starting with today's events
             self.eventscolumn.current_date = dt.date.today()
@@ -1255,11 +1265,12 @@ def _add_calendar_colors(palette, collection):
     return palette
 
 
-def start_pane(pane, callback, program_info='', quit_keys=['q']):
+def start_pane(pane, callback, program_info='', quit_keys=None):
     """Open the user interface with the given initial pane."""
+    quit_keys = quit_keys or ['q']
 
     frame = Window(
-        footer=program_info + ' | {}: quit, ?: help'.format(quit_keys[0]),
+        footer=program_info + f' | {quit_keys[0]}: quit, ?: help',
         quit_keys=quit_keys,
     )
 
@@ -1283,7 +1294,7 @@ def start_pane(pane, callback, program_info='', quit_keys=['q']):
         def format(self, record):
             return (
                 super().format(record)[:30] + '... '
-                '[Press `{}` to view log]'.format(pane._conf['keybindings']['log'][0])
+                f"[Press `{pane._conf['keybindings']['log'][0]}` to view log]"
             )
 
     class LogPaneHandler(logging.Handler):
@@ -1312,7 +1323,8 @@ def start_pane(pane, callback, program_info='', quit_keys=['q']):
         frame, palette, unhandled_input=frame.on_key_press, pop_ups=True)
     frame.loop = loop
 
-    def redraw_today(loop, pane, meta={'last_today': None}):
+    def redraw_today(loop, pane, meta=None):
+        meta = meta or {'last_today': None}
         # XXX TODO this currently assumes, today moves forward by exactly one
         # day, but it could either move forward more (suspend-to-disk/ram) or
         # even move backwards
